# Test Data

The data in this directory originate from [Red Hat Product Security SBOM examples](https://github.com/RedHatProductSecurity/security-data-guidelines/tree/main/sbom/examples)
and has been modified to match the validation needs. Namely:

- SPDXID can only contain alphanumerics, `-` and `.`
- License List version were added (just to be compatible with Guac)
